#extension GL_EXT_frag_depth : enable
#extension GL_EXT_shader_texture_lod : enable
#extension GL_OES_standard_derivatives : enable

uniform lowp float wavecongregation;
uniform lowp float speed;
uniform lowp float wavepower;
uniform lowp float wavecoeficient;
uniform lowp float epicenter;
uniform lowp float resolutionx;
uniform lowp float resolutiony;



/////////////////////////////////////////////////////////
// WavePulse
//uniform vec3 resolution; 
//varying vec2 fragCoord;
//uniform mediump vec4 fragColor;

varying mediump vec2 vTex;
//The foreground texture sampler, to be sampled at vTex
uniform lowp sampler2D samplerFront;
//The current foreground rectangle being rendered
uniform mediump vec2 srcStart;
uniform mediump vec2 srcEnd;
//The current foreground source rectangle being rendered
uniform mediump vec2 srcOriginStart;
uniform mediump vec2 srcOriginEnd;
//The current foreground source rectangle being rendered, in layout 
uniform mediump vec2 layoutStart;
uniform mediump vec2 layoutEnd;
//The background texture sampler used for background - blending effects
uniform lowp sampler2D samplerBack;
//The current background rectangle being rendered to, in texture co-ordinates, for background-blending effects
uniform mediump vec2 destStart;
uniform mediump vec2 destEnd;
//The time in seconds since the runtime started. This can be used for animated effects
uniform mediump float seconds;
//The size of a texel in the foreground texture in texture co-ordinates
uniform mediump vec2 pixelSize;
//The current layer scale as a factor (i.e. 1 is unscaled)
uniform mediump float layerScale;
//The current layer angle in radians.
uniform mediump float layerAngle;



const lowp float PI = 3.14159265359;

//float waveCongregation = 1.2;
//float speed = 2.0;
//float wavePower = 0.2;
//float waveCoeficient = 1.1;
//float epicenter = 0.5;

lowp float genWave(lowp float len)
{
  lowp float wave = sin(wavecongregation * PI * len - seconds*speed);
	lowp float wavePow = 1.0 - pow(abs(wave*wavecoeficient), wavepower);
	wave = wavePow * wave; 
	return wave;
}

void main(void)
{
	//vec2 uv = fragCoord.xy / resolution.xy;

	lowp vec2 pos2 = vec2(epicenter) - vTex; 
	lowp vec2 pos2n = normalize(pos2);
    
	lowp float len = length(pos2);
    lowp float dist = max(1. - len, 0.);
    
	lowp float wave = genWave(len); 

	lowp vec2 uv2 = pos2n * wave/(1.0 + 5.0 * len);
	//fragColor = vec4(texture(iChannel0, uv ));
	gl_FragColor = vec4(texture2D(samplerFront, vTex + uv2 * dist));
}